﻿'
' Copyright (c) 2021, MindFusion LLC - Bulgaria.
'

Imports System.IO
Imports Microsoft.Win32


Class MainWindow

	Public Sub New()

		InitializeComponent()

        diagram.DefaultShape = Shapes.Ellipse
		diagram.Bounds = New Rect(0, 0, 2000, 2000)

        Dim layout = New MindFusion.Diagramming.Wpf.Layout.AnnealLayout()

		iterationTxB.Text = layout.IterationsPerStage.ToString()
		stageTxB.Text = layout.Stages.ToString()
		initialTxB.Text = layout.InitialTemperature.ToString()
		tempScaleTxB.Text = layout.TemperatureScale.ToString()

		linkLengthFactorTxB.Text = layout.LinkLengthFactor.ToString()
		crossingArrowsCostTxB.Text = layout.CrossingLinksCost.ToString()
		distributionFactorTxB.Text = layout.DistributionFactor.ToString()
		nodeArrowDistFactorTxB.Text = layout.NodeLinkDistFactor.ToString()
        boundaryFactorTxB.Text = layout.BoundaryFactor.ToString()

        Try
			diagram.LoadFromXml("AnnealLayout")
		Catch exp As FileLoadException
			MessageBox.Show(exp.Message)
			Return
		Catch exp As Exception
			MessageBox.Show(exp.Message)
        End Try

        Dim shapeNodeStyle As New Style()
        shapeNodeStyle.Setters.Add(New Setter(ShapeNode.BrushProperty, _
          New LinearGradientBrush(Colors.White, Color.FromRgb(135, 206, 250), 5)))
        diagram.ShapeNodeStyle = shapeNodeStyle

	End Sub

	' open
	Private Sub button3_Click(ByVal sender As Object, ByVal e As RoutedEventArgs)
		Dim dlg = New OpenFileDialog()
		If dlg.ShowDialog() = True Then
			diagram.LoadFromXml(dlg.FileName)
		End If
	End Sub

	' save
	Private Sub button2_Click(ByVal sender As Object, ByVal e As RoutedEventArgs)
		Dim dlg = New SaveFileDialog()
		If dlg.ShowDialog() = True Then
			diagram.SaveToXml(dlg.FileName)
		End If
	End Sub

	' arrange
	Private Sub button1_Click(ByVal sender As Object, ByVal e As RoutedEventArgs)
		Dim layout = New MindFusion.Diagramming.Wpf.Layout.AnnealLayout()
		Dim initIter As Integer
		Dim initStages As Integer
		Dim initTemp As Double
		Dim initTempScale As Double
		Dim arrowLengthFactor As Double
		Dim crossingArrowsCost As Double
		Dim distributionFactor As Double
		Dim nodeArrowDistFactor As Double
		Dim boundaryFactor As Double

		Dim errorValue As [String] = ""

		Try
			errorValue = iterationTxB.Text
			initIter = Int32.Parse(iterationTxB.Text)
			errorValue = stageTxB.Text
			initStages = Int32.Parse(stageTxB.Text)
			errorValue = initialTxB.Text
			initTemp = [Double].Parse(initialTxB.Text)
			errorValue = tempScaleTxB.Text
			initTempScale = [Double].Parse(tempScaleTxB.Text)

			errorValue = linkLengthFactorTxB.Text
			arrowLengthFactor = [Double].Parse(linkLengthFactorTxB.Text)
			errorValue = crossingArrowsCostTxB.Text
			crossingArrowsCost = [Double].Parse(crossingArrowsCostTxB.Text)
			errorValue = distributionFactorTxB.Text
			distributionFactor = [Double].Parse(distributionFactorTxB.Text)
			errorValue = nodeArrowDistFactorTxB.Text
			nodeArrowDistFactor = [Double].Parse(nodeArrowDistFactorTxB.Text)
			errorValue = boundaryFactorTxB.Text

			boundaryFactor = [Double].Parse(boundaryFactorTxB.Text)
		Catch generatedExceptionName As Exception
			MessageBox.Show("Error! Incorrect input: " & errorValue)
			Return
		End Try

		layout.IterationsPerStage = Math.Max(1, initIter)
		layout.Stages = initStages
		layout.InitialTemperature = initTemp
		layout.TemperatureScale = initTempScale

		layout.LinkLengthFactor = arrowLengthFactor
		layout.CrossingLinksCost = crossingArrowsCost
		layout.DistributionFactor = distributionFactor
		layout.NodeLinkDistFactor = nodeArrowDistFactor
		layout.BoundaryFactor = boundaryFactor

		layout.Arrange(diagram)
		diagram.ResizeToFitItems(50, True)
	End Sub

End Class
